@@ -2,10 +2,9 @@ from seamapi.types import (
     AbstractLocks,
     Device,
     DeviceId,
-    ActionAttempt,
     AbstractSeam as Seam,
 )
-from typing import List, Union
+from typing import List, Union, Optional
 import requests
 
 
@@ -21,9 +20,10 @@ class Locks(AbstractLocks):
     def __init__(self, seam: Seam):
         self.seam = seam
 
-    def list(self) -> List[Device]:
+    def list(self, connected_account: Optional[str] = None) -> List[Device]:
         res = requests.post(
             f"{self.seam.api_url}/locks/list",
+            params={"connected_account_id": connected_account},
             headers={"Authorization": f"Bearer {self.seam.api_key}"},
         )
         if not res.ok:
@@ -43,7 +43,7 @@ class Locks(AbstractLocks):
         json_lock = res.json()["device"]
         return Device.from_dict(json_lock)
 
-    def lock_door(self, device: Union[DeviceId, Device]) -> ActionAttempt:
+    def lock_door(self, device: Union[DeviceId, Device]) -> None:
         device_id = to_device_id(device)
         res = requests.post(
             f"{self.seam.api_url}/locks/lock_door",
@@ -52,9 +52,8 @@ class Locks(AbstractLocks):
         )
         if not res.ok:
             raise Exception(res.text)
-        return ActionAttempt(action_attempt_id="", status="pending")
 
-    def unlock_door(self, device: Union[DeviceId, Device]) -> ActionAttempt:
+    def unlock_door(self, device: Union[DeviceId, Device]) -> None:
         device_id = to_device_id(device)
         res = requests.post(
             f"{self.seam.api_url}/locks/unlock_door",
@@ -63,4 +62,3 @@ class Locks(AbstractLocks):
         )
         if not res.ok:
             raise Exception(res.text)
-        return ActionAttempt(action_attempt_id="", status="pending")
